netapp_ontap.models.aggregate_block_storage_hybrid_cache_storage_pools API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_block_storage_hybrid_cache_storage_pools`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateBlockStorageHybridCacheStoragePoolsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateBlockStorageHybridCacheStoragePools object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allocation_units_count: Size GET POST PATCH`

    Allocation count of storage pool.

  `storage_pool: StoragePool GET POST PATCH`

    The storage_pool field of the aggregate_block_storage_hybrid_cache_storage_pools.